''      By Shawn A.
''
'' This is just a basic program to read the raw ACC readings from a ADXL345 3 axis accelerometer and convert the X and Y axis to an angle
'' using the ATAN2 function. Then convert the Floating Point values to integers to display in PST.
'' I believe ideally one would zero the ACC before doing any of this.
'' I am using a 6DOF board from SparkFun

CON
        _clkmode = xtal1 + pll16x
        _xinfreq = 5_000_000

MHZ   = 80
OHund = 100.0
OBJ
FP32F    : "Float32Full"               'By Cam Thompson
Acc      : "ITG 3200 Sport pasm"       'By Jason Dorie                      
PST      : "Parallax Serial Terminal"  'By Jeff Martin, Andy Lindsay, Chip Gracey

VAR
  Long Roll, Pitch 
  Long Ax, Ay, Az
  
PUB Main

''''''Initializes a Couple of Things''''''
  PST.Start(115_200)        'Sets BaudRate for PST.
  PST.Clear                 'Clears PST Screen.
  FP32F.Start               'Starts Math Engine FF32.
  Acc.Start(6,7)            'Starts ACC Sets I2C Pins.

Repeat
'
''''''Read Raw Values from ACC''''''''
    Ax    := Acc.GetAx
    Ay    := Acc.GetAY
    Az    := Acc.GetAz

'''''''Convert ACC Raw Values to Floating Point''''''''
    Ax    := FP32F.FFloat(Ax)
    Ay    := FP32F.FFloat(Ay)
    Az    := FP32F.FFloat(Az)

 ''''''Preforms ATAN2 Function then Converts to Degrees for X Axis''''''
 ''''''Acc_X_Angle = ATAN2(X_ AccValue,Z_AccValue)
    Roll  := FP32F.ATan2(Ax,Az)
    Roll  := FP32F.Degrees(Roll)
 ''''''Preforms ATAN2 Function then Converts to Degrees for Y Axis''''''    
 ''''''Acc_Y_Angle = ATAN2(Y_ AccValue,Z_AccValue)
    Pitch := FP32F.ATan2(Ay,Az)
    Pitch := FP32F.Degrees(Pitch)

 ''''''Converts Roll and Pitch to Integers to Display in PST''''''
 'Converts Degrees into Integers, I take Roll and Pitch * 100 so that I can see 2 Decimal Places in the Result.
 'For Example 90 Degrees would Read 9000 Degrees
    Roll  := FP32F.FMul(OHund,Roll)
    Pitch := FP32F.FMul(OHund,Pitch)
'
'''''Rounds Roll and then Pitch and Converts to Integers''''''
    Roll  := FP32F.FRound(Roll)
    Pitch := FP32F.FRound(Pitch)

''''''Displays Roll and Pitch in PST Window''''''
    PST.Clear
    PST.Char("X")
    PST.Char("=")
    PST.Char(" ")
    PST.Dec(Roll)
    PST.NewLine
    PST.Char("Y")
    PST.Char("=")
    PST.Char(" ")
    PST.Dec(Pitch)
    waitcnt(clkfreq/2 + cnt)    'Repeat Loop 2 Times a Second.
